@@ -9,7 +9,7 @@ try:
 except:
     from default import DEBUG
 
-MAX_ATTEMPTS = 3
+MAX_ATTEMPTS = 20
 logging.basicConfig()
 logger = logging.getLogger("tcpy.connection")
 if DEBUG:
@@ -77,7 +77,7 @@ class ClientConnection(object):
                 logger.debug("Client sending bytes to server.")
                 self.sock.sendall(len_to_prefix(len(msg)))
                 self.sock.sendall(msg)
-                logger.debug("Client sent %s bytes to server." % len_to_prefix(len(msg)))
+                logger.debug("Client sent %s bytes to server." % len(msg))
                 self.attempts = 0
                 break
             except socket.error:
@@ -125,7 +125,7 @@ class ServerConnection(object):
             logger.debug("Server sent %s bytes to client." % len(msg))
         except socket.error:
             self.finish()
-            raise Exception('ServerConnection failed to send %s.' % data)
+            logger.exception('ServerConnection failed to send %s.' % data)
 
     def read(self):
         logger.debug("Server waiting for bytes from client.")
